==> FitGallery-0.80.tar.gz: FitGallery-0.80/index.php <==
<?php

# FitGallery 0.80 copyleft GPL by Pollo (magura@ardilla.dyndns.org) and Presi (presi@confluencia.net)
# http://fitgallery.presi.org

# view gallery thumbs page file

include 'config-dirgal.php';

if (file_exists('config_gals.php')) { include 'config_gals.php'; }
else { include 'config.php'; }

include 'config-lang.php';

$version="0.80";
$dirimgs="imgs";
$lineas=file($titulo);
$n=0;
$total=0;
$subtotal=0;
$numimgs=0;

echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
<!-- FitGallery 0.80 copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->
<html>
<head>
<style type="text/css">
<!--';
if (file_exists('ver_gals.css.php')) { include 'ver_gals.css.php'; }
else { include 'default.css.php'; }
echo '-->
</style>
<title>'.$lineas[0].'</title>
</head>
<body>
<h3 class="center">'.$lineas[0].'</h3>
';


$handle=opendir($dirgal); 
while ($file = readdir($handle))
{ 
 if ($file != "." && $file != ".." && is_dir("$dirgal/$file"))
  {
    $arr[$n][0]=filemtime("$dirgal/$file");
    $arr[$n][1]=$file;
    $handledir=opendir("$dirgal/$file/$dirimgs");
    $primero="x";
    while ($fileimgs = readdir($handledir))
     {
       if ($fileimgs != "." && $fileimgs != "..")
        {
          if ($primero == "x") $primero=$fileimgs;
          $subtotal += filesize("$dirgal/$file/$dirimgs/$fileimgs");
          $numimgs += 1;
        }
     }
    $arr[$n][2]=$subtotal;
    $subtotal=0;
    $arr[$n][3]=$numimgs;
    $numimgs=0;
    $arr[$n][4]=$primero;
    $n++;
  }
}
closedir($handle); 

sort($arr);
$numero_arch=count($arr);

settype($para, "integer");
$para=$_GET["para"];
if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
$para=intval($para);

$desde=$para+1;
$avmenosuno=$avance-1;
$hasta=$desde+$avmenosuno;
if ($hasta>$numero_arch) $hasta=$numero_arch;

echo "<h4 class=\"center\">$desde-$hasta</h4>\n";

$para2=$para+($avmenosuno);
$nummenosuno=$numero_arch-1;
if ($para2 >= $numero_arch) $para2 = $nummenosuno;
for ( $i=$para ; $i <= $para2 ; $i++) 
{
   $valor=$arr[$i][1];
   $size=$arr[$i][3];
   $bytes=$arr[$i][2];
   $megas=$bytes/10485.76;
   $megas=round($megas)/100;
   $fecha=date("d/m/Y H:i:s",$arr[$i][0]);
   $portada=$arr[$i][4];
   $total += $bytes;

   echo "
   <div class=\"figure\">
   <a href=\"ver_thumb.php?galeria=$valor\">
   <img class=\"sinborde\" src=\"thumb.php?galeria=$valor&amp;valor=$portada&amp;horiz=$h_thumb&amp;tipo=t\" alt=\"$valor\">
   </a>
   <p class=\"caption\">";
   echo $i+1;
   echo ". ";
   echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$valor\">
   $valor<br>
   </a>";
   readfile("$dirgal/$valor/$titulo");
   echo "<br>\n $size images<br>
   $bytes bytes ($megas MB)<br>
   $fecha
   </p>
   </div>
";
}

$numer_pag=$nummenosuno/$avance;
settype($numer_pag, "integer");

echo "
<p class=\"clear\">
<br>
<strong>$text_galerias</strong>";

for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
{
   $cuentaantmenosuno=$cuentaant-1;
   if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_gals.php?para=$cuentaantmenosuno\">";
   echo "$cuentaant-$cuenta";
   if ($cuentaant!=$desde) echo "</a>";
   echo " | ";
   $cuentaant=$cuenta+1;
   $cuenta=$cuenta+$avance;
}

$cuentaantmenosuno=$cuentaant-1;
$totalmegas=$total/10485.76;
$totalmegas=round($totalmegas)/100;
if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_gals.php?para=$cuentaantmenosuno\">";
echo "$cuentaant-$numero_arch";
if ($cuentaant!=$desde) echo "</a>";
echo '</p>
<p class="clear">
';
$anterior=$para-$avance;
$siguiente=$para+$avance;
if ($anterior<0) echo $text_anterior;
            else echo "<a class=\"texto\" href=\"ver_gals.php?para=$anterior\">$text_anterior</a>";
print " | ";
if ($siguiente>$cuentaantmenosuno) echo $text_siguiente;
            else echo "<a class=\"texto\" href=\"ver_gals.php?para=$siguiente\">$text_siguiente</a>";
echo "</p>
<p class=\"center\">
$text_totales$total ($totalmegas MB)
</p>
<p class=\"center\">
<a href=\"http://validator.w3.org/check/referer\">
<img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
</a>
</p>";

if (powered) echo "<p class=\"center\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";

echo "</body>
</html>";

?>

==> FitGallery-0.81.tar.gz: FitGallery-0.81/index.php <==
<?php

# FitGallery 0.81 copyleft GPL by Pollo (magura@ardilla.dyndns.org) and Presi (presi@confluencia.net)
# http://fitgallery.presi.org

# view gallery thumbs page file

include 'config/config-thumb.php';

if (file_exists('config/config_gals.php')) { include 'config/config_gals.php'; }
else { include 'config/config.php'; }

include 'config/config-lang.php';

$version="0.81";
$dirimgs="imgs";
$linea_titulo=file($titulo);
$n=0;
$total=0;
$subtotal=0;
$numimgs=0;

echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
<!-- FitGallery 0.81 copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->
<html>
<head>
<style type="text/css">
<!--';
if (file_exists('config/ver_gals.css.php')) { include 'config/ver_gals.css.php'; }
else { include 'config/default.css.php'; }
echo '-->
</style>
<title>'.strip_tags($linea_titulo[0]).'</title>
</head>
<body>
<h3 class="center">';
include "$titulo";
echo '</h3>
';


$handle=opendir($dirgal); 
while ($file = readdir($handle))
{ 
 if ($file != "." && $file != ".." && is_dir("$dirgal/$file"))
  {
    $arr[$n][0]=filemtime("$dirgal/$file");
    $arr[$n][1]=$file;
    $handledir=opendir("$dirgal/$file/$dirimgs");
    $primero="x";
    while ($fileimgs = readdir($handledir))
     {
       if ($fileimgs != "." && $fileimgs != "..")
        {
          if ($primero == "x") $primero=$fileimgs;
          $subtotal += filesize("$dirgal/$file/$dirimgs/$fileimgs");
          $numimgs += 1;
        }
     }
    $arr[$n][2]=$subtotal;
    $subtotal=0;
    $arr[$n][3]=$numimgs;
    $numimgs=0;
    $arr[$n][4]=$primero;
    $n++;
  }
}
closedir($handle); 

sort($arr);
$numero_arch=count($arr);

settype($para, "integer");
$para=$_GET["para"];
if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
$para=intval($para);

$desde=$para+1;
$avmenosuno=$avance-1;
$hasta=$desde+$avmenosuno;
if ($hasta>$numero_arch) $hasta=$numero_arch;

echo "<h4 class=\"center\">$desde-$hasta</h4>\n
<h4 class=\"center\">";
include "$subtitulo";
echo "</h4>\n";

$para2=$para+($avmenosuno);
$nummenosuno=$numero_arch-1;
if ($para2 >= $numero_arch) $para2 = $nummenosuno;
for ( $i=$para ; $i <= $para2 ; $i++) 
{
   $valor=$arr[$i][1];
   $size=$arr[$i][3];
   $bytes=$arr[$i][2];
   $megas=$bytes/10485.76;
   $megas=round($megas)/100;
   $fecha=date("d/m/Y H:i:s",$arr[$i][0]);
   $portada=$arr[$i][4];
   $total += $bytes;

   echo "
   <div class=\"figure\">
   <a href=\"ver_thumb.php?galeria=$valor\">
   <img class=\"sinborde\" src=\"thumb.php?galeria=$valor&amp;valor=$portada&amp;horiz=$h_thumb&amp;tipo=t\" alt=\"$valor\">
   </a>
   <p class=\"caption\">";
   echo $i+1;
   echo ". ";
   echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$valor\">
   $valor<br>
   </a>";
   readfile("$dirgal/$valor/$titulo");
   echo "<br>\n $size $text_images<br>
   $bytes bytes ($megas MB)<br>
   $fecha
   </p>
   </div>
";
}

$numer_pag=$nummenosuno/$avance;
settype($numer_pag, "integer");

echo "
<p class=\"clear\">
<br>
<strong>$text_pages:</strong> ";

for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
{
   $cuentaantmenosuno=$cuentaant-1;
   if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_gals.php?para=$cuentaantmenosuno\">";
   echo "$cuentaant-$cuenta";
   if ($cuentaant!=$desde) echo "</a>";
   echo " | ";
   $cuentaant=$cuenta+1;
   $cuenta=$cuenta+$avance;
}

$cuentaantmenosuno=$cuentaant-1;
$totalmegas=$total/10485.76;
$totalmegas=round($totalmegas)/100;
if ($cuentaant!=$desde) echo "<a class=\"texto\" href=\"ver_gals.php?para=$cuentaantmenosuno\">";
echo "$cuentaant-$numero_arch";
if ($cuentaant!=$desde) echo "</a>";
echo '</p>
<p class="clear">
';
$anterior=$para-$avance;
$siguiente=$para+$avance;
if ($anterior<0) echo $text_anterior;
            else echo "<a class=\"texto\" href=\"ver_gals.php?para=$anterior\">$text_anterior</a>";
print " | ";
if ($siguiente>$cuentaantmenosuno) echo $text_siguiente;
            else echo "<a class=\"texto\" href=\"ver_gals.php?para=$siguiente\">$text_siguiente</a>";
echo "</p>
<p class=\"center\">
$text_totales$total ($totalmegas MB)
</p>
<p class=\"center\">
<a href=\"http://validator.w3.org/check/referer\">
<img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
</a>
</p>";

if (powered) echo "<p class=\"center\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";

echo "</body>
</html>";

?>
